@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries without C or XS
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -53,7 +53,12 @@ sub new
       croak "lib argument must be a scalar or array reference";
     }
   }
-  bless { lib => \@lib, handles => {}, types => {} }, $class;
+  bless {
+    lib              => \@lib,
+    handles          => {},
+    types            => {},
+    ignore_not_found => defined $args{ignore_not_found} ? $args{ignore_not_found} : 0,
+  }, $class;
 }
 
 
@@ -70,6 +75,19 @@ sub lib
 }
 
 
+sub ignore_not_found
+{
+  my($self, $value) = @_;
+  
+  if(defined $value)
+  {
+    $self->{ignore_not_found} = $value;
+  }
+  
+  $self->{ignore_not_found};
+}
+
+
 sub type
 {
   my($self, $name, $alias) = @_;
@@ -208,7 +226,8 @@ sub function
   my @args = map { $self->_type_lookup($_) || croak "unknown type: $_" } @$args;
   $ret = $self->_type_lookup($ret) || croak "unknown type: $ret";
   my $address = $name =~ /^-?[0-9]+$/ ? $name : $self->find_symbol($name);
-  croak "unable to find $name" unless defined $address;
+  croak "unable to find $name" unless defined $address || $self->ignore_not_found;
+  return unless defined $address;
   FFI::Platypus::Function->new($self, $address, $ret, @args);
 }
 
@@ -223,11 +242,14 @@ sub attach
   
   my $function = $self->function($c_name, $args, $ret);
   
-  my($caller, $filename, $line) = caller;
-  $perl_name = join '::', $caller, $perl_name
-    unless $perl_name =~ /::/;
+  if(defined $function)
+  {
+    my($caller, $filename, $line) = caller;
+    $perl_name = join '::', $caller, $perl_name
+      unless $perl_name =~ /::/;
     
-  $function->attach($perl_name, "$filename:$line", $proto);
+    $function->attach($perl_name, "$filename:$line", $proto);
+  }
   
   $self;
 }
@@ -287,6 +309,32 @@ sub find_symbol
 }
 
 
+sub package
+{
+  my($self, $module, $modlibname) = @_;
+  
+  require FFI::Platypus::ConfigData;
+  my $dlext = FFI::Platypus::ConfigData->config("config_dlext");
+
+  ($module, $modlibname) = caller() unless defined $modlibname;  
+  my @modparts = split /::/, $module;
+  my $modfname = $modparts[-1];
+  my $modpname = join('/',@modparts);
+  my $c = @modparts;
+  $modlibname =~ s,[\\/][^\\/]+$,, while $c--;    # Q&D basename
+  my $file = "$modlibname/auto/$modpname/$modfname.$dlext";
+  unless(-e $file)
+  {
+    $modlibname =~ s,[\\/][^\\/]+$,,;
+    $file = "$modlibname/arch/auto/$modpname/$modfname.$dlext";
+  }
+  
+  $self->lib($file) if -e $file;
+  
+  $self;
+}
+
+
 sub DESTROY
 {
   my($self) = @_;
@@ -300,7 +348,7 @@ sub DESTROY
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -312,7 +360,7 @@ package FFI::Platypus::Closure;
 use Scalar::Util qw( refaddr);
 use Carp qw( croak );
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 our %cbdata;
 
@@ -339,13 +387,13 @@ sub DESTROY
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 sub new
 {
@@ -405,7 +453,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries without C or XS
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -516,6 +564,12 @@ the L<lib|FFI::Platypus#lib> attribute.
 Either a pathname (string) or a list of pathnames (array ref of strings) 
 to pre-populate the L<lib|FFI::Platypus#lib> attribute.
 
+=item ignore_not_found
+
+[version 0.15]
+
+Set the L<ignore_not_found|FFI::Platypus#ignore_not_found> attribute.
+
 =back
 
 =head1 ATTRIBUTES
@@ -548,6 +602,24 @@ mostly useful for finding functions in the standard C library, without
 having to know the name of the standard c library for your platform (as 
 it turns out it is different just about everywhere!).
 
+=head2 ignore_not_found
+
+[version 0.15]
+
+ $ffi->ignore_not_found(1);
+ my $ignore_not_found = $ffi->ignore_not_found;
+
+Normally the L<attach|FFI::Platypus#attach> and 
+L<function|FFI::Platypus#function> methods will throw an exception if it 
+cannot find the name of the function you provide it.  This will change 
+the behavior such that L<function|FFI::Platypus#function> will return 
+C<undef> when the function is not found and 
+L<attach|FFI::Platypus#attach> will ignore functions that are not found. 
+This is useful when you are writing bindings to a library and have many 
+optional functions and you do not wish to wrap every call to 
+L<function|FFI::Platypus#function> or L<attach|FFI::Platypus#attach> in 
+an C<eval>.
+
 =head1 METHODS
 
 =head2 type
@@ -745,6 +817,16 @@ iterations.
 
 Return the address of the given symbol (usually function).
 
+=head2 package
+
+ $ffi->package($package, $file); # usually __PACKAGE__ and __FILE__ can be used
+ $ffi->package;                  # autodetect
+
+If you have used L<Module::Build::FFI> to bundle C code with your
+distribution, you can use this method to tell the L<FFI::Platypus> instance
+to look for symbols that came with the dynamic library that was built
+when your distribution was installed.
+
 =head1 EXAMPLES
 
 Here are some examples.  Some of them use the L<FFI::Platypus::Declare> 
@@ -1295,6 +1377,10 @@ Memory functions for FFI.
 
 Find dynamic libraries in a portable way.
 
+=item L<Module::Build::FFI>
+
+Bundle C code with your FFI extension.
+
 =item L<FFI::TinyCC>
 
 JIT compiler for FFI.
