@@ -5,7 +5,7 @@ use warnings;
 use FFI::Platypus;
 
 # ABSTRACT: Declarative interface to FFI::Platypus
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 our $ffi    = {};
@@ -13,8 +13,8 @@ our $types  = {};
 
 sub _ffi_object
 {
-  my $caller = caller(1);
-  $ffi->{$caller} ||= FFI::Platypus->new;
+  my($package, $filename) = caller(1);
+  $ffi->{$package} ||= FFI::Platypus->new->package($package,$filename);
 }
 
 
@@ -143,7 +143,7 @@ FFI::Platypus::Declare - Declarative interface to FFI::Platypus
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
