@@ -12,15 +12,15 @@ use Config;
 use base qw( Module::Build );
 
 # ABSTRACT: Build Perl extensions in C with FFI
-our $VERSION = '0.42_01'; # TRIAL VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 __PACKAGE__->add_property( ffi_libtest_dir =>
-  default => [ 'libtest' ],
+  default => 'libtest',
 );
 
 __PACKAGE__->add_property( ffi_include_dir =>
-  default => [ 'include' ],
+  default => 'include',
 );
 
 __PACKAGE__->add_property( ffi_libtest_optional =>
@@ -28,35 +28,24 @@ __PACKAGE__->add_property( ffi_libtest_optional =>
 );
 
 __PACKAGE__->add_property( ffi_source_dir => 
-  default => [ 'ffi' ],
+  default => 'ffi',
 );
 
-sub _inflate ($)
-{
-  my($self) = @_;
-  $self->ffi_source_dir([$self->ffi_source_dir])
-    unless ref $self->ffi_source_dir;
-
-  $self->ffi_libtest_dir([$self->ffi_libtest_dir])
-    unless ref $self->ffi_libtest_dir;
-}
-
 sub new
 {
   my($class, %args) = @_;
 
   my $self = $class->SUPER::new(%args);
 
-  _inflate($self);
-  my $have_compiler = $self->ffi_have_compiler;
+  my $have_compiler = ExtUtils::CBuilder->new->have_compiler;
 
-  if(-d $self->ffi_source_dir->[0] && !$have_compiler)
+  if(-d $self->ffi_source_dir && !$have_compiler)
   {
     print STDERR "This distribution requires a compiler\n";
     exit;
   }
   
-  if(-d $self->ffi_libtest_dir->[0] && !$self->ffi_libtest_optional && !$have_compiler)
+  if(-d $self->ffi_libtest_dir && !$self->ffi_libtest_optional && !$have_compiler)
   {
     print STDERR "This distribution requires a compiler\n";
     exit;
@@ -65,36 +54,14 @@ sub new
   $self;
 }
 
-
-my @cpp_extensions = qw( c cpp cxx cc c++ );
-
-sub ffi_have_compiler
-{
-  my($self) = @_;
-  
-  my $cpp = 0;
-  
-  foreach my $dir (@{ $self->ffi_source_dir }, @{ $self->ffi_libtest_dir })
-  {
-    next unless -d $dir;
-    $cpp = 1 if scalar map { bsd_glob("$dir/*.$_") } @cpp_extensions;
-  }
-  
-  my $cb = $self->cbuilder;
-  $cpp ? $cb->have_cplusplus && $cb->have_compiler : $cb->have_compiler;
-}
-
-
 sub _ffi_headers ($$)
 {
   my($self, $dir) = @_;
 
   my @headers;
-  
-  my @dirs = @$dir;
-  push @dirs, grep { -d $_ } ref $self->ffi_include_dir ? @{ $self->ffi_include_dir } : ($self->ffi_include_dir);
-
-  push @headers, map { bsd_glob("$_/*.h") } @dirs;
+  push @headers, bsd_glob($self->ffi_include_dir . "/*.h")
+    if -d $self->ffi_include_dir;
+  push @headers, bsd_glob("$dir/*.h");
   
   \@headers;
 }
@@ -103,9 +70,10 @@ sub _ffi_include_dirs ($$)
 {
   my($self, $dir) = @_;
   
-  my @includes = (@$dir);
+  my @includes = ($dir);
 
-  push @includes, grep { -d $_ } ref $self->ffi_include_dir ? @{ $self->ffi_include_dir } : ($self->ffi_include_dir);
+  push @includes, $self->ffi_include_dir
+    if defined $self->ffi_include_dir;
 
   push @includes, $ENV{FFI_PLATYPUS_INCLUDE_DIR} || File::Spec->catdir(File::ShareDir::dist_dir('FFI-Platypus'), 'include');
 
@@ -115,46 +83,33 @@ sub _ffi_include_dirs ($$)
   \@includes;
 }
 
-
-sub ffi_build_dynamic_lib ($$$;$)
+sub _build_dynamic_lib ($$$;$)
 {
-  my($self, $dirs, $name, $dest_dir) = @_;
+  my($self, $dir, $name, $dest_dir) = @_;
   
-  $dest_dir ||= $dirs->[0];
+  $dest_dir ||= $dir;
   
-  my $header_time = do {
-    my @list = sort map { (stat $_)[9] } @{ _ffi_headers $self, $dirs };
-    pop @list;
-  } || 0;
+  my $header_time = do { no warnings; reverse sort map { (stat $_)[9] } @{ _ffi_headers $self, $dir } };
   my $compile_count = 0;
-  my $b = $self->cbuilder;
+  my $b = ExtUtils::CBuilder->new;
 
-  my @obj;
-  
-  foreach my $dir (@$dirs)
-  {
-    push @obj,  map {
-      my $filename = $_;
-      my($source_time) = reverse sort ((stat $filename)[9], $header_time);
-      my $obj_name = $b->object_file($filename);
-      $self->add_to_cleanup($obj_name);
-      my $obj_time = -e $obj_name ? ((stat $obj_name)[9]) : 0;
-
-      my %compile_options = (
+  my @obj = map {
+    my $filename = $_;
+    my($source_time) = reverse sort ((stat $filename)[9], $header_time);
+    my $obj_name = $b->object_file($filename);
+    $self->add_to_cleanup($obj_name);
+    my $obj_time = -e $obj_name ? ((stat $obj_name)[9]) : 0;
+    if($obj_time < $source_time)
+    {
+      $b->compile(
         source               => $filename,
-        include_dirs         => _ffi_include_dirs($self, $dirs),
+        include_dirs         => _ffi_include_dirs($self, $dir),
         extra_compiler_flags => $self->extra_compiler_flags,
       );
-      $compile_options{"C++"} = 1 if $filename =~ /\.(cpp|cxx|cc|\c\+\+)$/;
-
-      if($obj_time < $source_time)
-      {
-        $b->compile(%compile_options);
-        $compile_count++;
-      }
-      $obj_name;
-    } sort map { bsd_glob("$dir/*.$_") } qw( c cpp cxx cc c++ s );
-  }
+      $compile_count++;
+    }
+    $obj_name;
+  } bsd_glob("$dir/*.c");
 
   return unless $compile_count > 0;
 
@@ -191,38 +146,27 @@ sub ffi_build_dynamic_lib ($$$;$)
   }
 }
 
-
-sub ffi_dlext
-{
-  require FFI::Platypus::ConfigData;
-  @{ FFI::Platypus::ConfigData->config('config_dlext') };
-}
-
 sub _ffi_libtest_name ()
 {
-  $^O eq 'cygwin' ? 'cygtest-1' : $^O eq 'msys' ? 'msys-test-1' : 'libtest';
+  $^O eq 'cygwin' ? 'cygtest-1' : 'libtest';
 }
 
 sub ACTION_libtest
 {
   my $self = shift;
-  _inflate($self);
-  my @dirs = @{ $self->ffi_libtest_dir };
+  my $dir = $self->ffi_libtest_dir;
   
-  return unless -d $dirs[0];
+  return unless -d $dir;
   
-  foreach my $dir (@dirs)
-  {
-    $self->add_to_cleanup(map { "$dir/$_" } qw(
-      *.o
-      *.obj
-      *.so
-      *.dll
-      *.bundle
-    ));
-  }
+  $self->add_to_cleanup(map { "$dir/$_" } qw(
+    *.o
+    *.obj
+    *.so
+    *.dll
+    *.bundle
+  ));
   
-  my $have_compiler = $self->ffi_have_compiler;
+  my $have_compiler = ExtUtils::CBuilder->new->have_compiler;
   
   unless($have_compiler)
   {
@@ -231,29 +175,25 @@ sub ACTION_libtest
     return;
   }
   
-  $self->ffi_build_dynamic_lib(\@dirs, _ffi_libtest_name);
+  _build_dynamic_lib $self, $dir, _ffi_libtest_name;
 }
 
 sub ACTION_ffi
 {
   my $self = shift;
-  _inflate($self);
-  my @dirs = @{ $self->ffi_source_dir };
+  my $dir = $self->ffi_source_dir;
   
-  return unless -d $dirs[0];
+  return unless -d $dir;
   
-  foreach my $dir (@dirs)
-  {
-    $self->add_to_cleanup(map { "$dir/$_" } qw(
-      *.o
-      *.obj
-      *.so
-      *.dll
-      *.bundle
-    ));
-  }
+  $self->add_to_cleanup(map { "$dir/$_" } qw(
+    *.o
+    *.obj
+    *.so
+    *.dll
+    *.bundle
+  ));
   
-  unless($self->ffi_have_compiler)
+  unless(ExtUtils::CBuilder->new->have_compiler)
   {
     print STDERR "a compiler is required.\n";
     exit 2;
@@ -272,7 +212,7 @@ sub ACTION_ffi
     $name = "$name.xs";
   }
 
-  $self->ffi_build_dynamic_lib(\@dirs, $name, $arch_dir);
+  _build_dynamic_lib $self, $dir, $name, $arch_dir;  
 }
 
 sub ACTION_build
@@ -303,7 +243,7 @@ Module::Build::FFI - Build Perl extensions in C with FFI
 
 =head1 VERSION
 
-version 0.42_01
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -338,13 +278,13 @@ Attach it to Perl in your main module (C<lib/Foo/Bar.pm>):
 
  package Foo::Bar;
  
- use FFI::Platypus;
+ use FFI::Platypus::Declare qw( void );
+ use FFI::Util qw( locate_module_share_lib );
  
- my $ffi = FFI::Platypus->new;
- $ffi->package;  # search for symbols in your bundled C code
- $ffi->attach( hello_world => [] => 'void');
+ lib locate_module_share_lib();
+ attach hello_world => [] => void;
 
-Finally, use it from your perl script or module:
+Use it from your perl script or module:
 
  use Foo::Bar;
  Foo::Bar::hello_world();  # prints "hello world\n"
@@ -365,10 +305,6 @@ By default, C source files in the C<ffi> directory are compiled and
 linked, if that directory exists.  You can change that directory
 with this property.
 
-[version 0.18]
-
-This can be a scalar or a array reference.
-
 =item ffi_libtest_dir
 
 [version 0.15]
@@ -379,14 +315,10 @@ can use to test your FFI module with.  You can use FFI::CheckLib to
 find the library from your test:
 
  use Test::More;
- use FFI::Platypus;
+ use FFI::Platypus::Declare;
  use FFI::CheckLib;
  
- FFI::Platypus->new->lib(find_lib lib => 'test', libpath => 'libtest');
-
-[version 0.18]
-
-This can be a scalar or a array reference.
+ lib find_lib lib => 'test', libpath => 'libtest';
 
 =item ffi_include_dir
 
@@ -396,10 +328,6 @@ If there is an C<include> directory with your distribution with C header
 files in it, it will be included in the search path for the C files in
 both the C<ffi> and C<libtest> directories.
 
-[version 0.18]
-
-This can be a scalar or a array reference.
-
 =item ffi_libtest_optional
 
 [version 0.15]
@@ -465,61 +393,9 @@ Microsoft Visual C++, but it may be necessary elsewhere in the future.
 
 =back
 
-=head1 METHODS
-
-=head2 ffi_have_compiler
-
-[version 0.18]
-
- my $has_compiler = $mb->ffi_have_compiler;
-
-Returns true if a C or C++ compiler is available.
-
-Only checks for C++ if you appear to have C++ source.
-
-Override for other foreign language subclasses.
-
-=head2 ffi_build_dynamic_lib
-
-[version 0.18]
-
- my $dll_path = $mb->ffi_build_dynamic_lib($src_dir, $name, $target_dir);
- my $dll_path = $mb->ffi_build_dynamic_lib($src_dir, $name);
-
-Compiles the C and C++ source in the C<$src_dir> and link it into a
-dynamic library with base name of C<$name.$Config{dlext}>.  If
-C<$target_dir> is specified then the dynamic library will be delivered
-into that directory.
-
-Override for other foreign language subclasses.
-
-=head2 ffi_dlext
-
- my @dlext = Module::Build::FFI->ffi_dlext;
-
-Returns a list of legal dynamic library extensions.  C<$Config{dlext}> is good,
-but many platforms use more than one extension for dynamic libraries.  For
-example, on Mac OS X, there are two different dynamic library types C<.bundle>
-and C<.dylib> and sometimes these renamed C<.so> files.  Although C<.bundle>
-and C<.dylib> have subtle differences, they can both be used by L<FFI::Platypus>.
-
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Bakkiaraj Murugesan (bakkiaraj)
-
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
